@@ -5,6 +5,7 @@ A background predictor is a function that accepts a single argument list
 and returns whether or not the process can be run in the background (returns
 True) or must be run the foreground (returns False).
 """
+
 import argparse
 import collections.abc as cabc
 import os
@@ -13,9 +14,63 @@ import time
 import typing as tp
 from pathlib import Path
 
-from xonsh.lazyasd import lazyobject
+from xonsh.lib.lazyasd import lazyobject
 from xonsh.platform import ON_POSIX, ON_WINDOWS, pathbasename
-from xonsh.tools import executables_in
+from xonsh.procs.executables import (
+    get_paths,
+    get_possible_names,
+    is_executable_in_posix,
+    is_executable_in_windows,
+)
+
+
+class CaseInsensitiveDict(dict[tp.Any, tp.Any]):
+    def __init__(self, *args, **kwargs):
+        super().__init__()
+        self._store = {}
+        self.update(*args, **kwargs)
+
+    def __setitem__(self, key, value):
+        # Store the key in lowercase but preserve the original case for display
+        self._store[key.casefold()] = key
+        super().__setitem__(key.casefold(), value)
+
+    def __getitem__(self, key):
+        return super().__getitem__(key.casefold())
+
+    def __delitem__(self, key):
+        del self._store[key.casefold()]
+        super().__delitem__(key.casefold())
+
+    def __contains__(self, key):
+        return key.casefold() in self._store
+
+    def get(self, key, default=None):
+        return super().get(key.casefold(), default)
+
+    def update(self, *args, **kwargs):
+        for k, v in dict(*args, **kwargs).items():
+            self[k] = v
+
+    def keys(self):
+        # Return the original keys with their original casing
+        return (self._store[k] for k in self._store)
+
+    def items(self):
+        return ((self._store[k], self[k]) for k in self._store)
+
+    def __repr__(self):
+        return f"{self.__class__.__name__}({dict(self.items())})"
+
+    def copy(self):
+        return CaseInsensitiveDict(self.items())
+
+
+CacheDict: tp.Union[type[CaseInsensitiveDict], type[dict]]
+if ON_WINDOWS:
+    CacheDict = CaseInsensitiveDict
+else:
+    CacheDict = dict
 
 
 class _Commands(tp.NamedTuple):
@@ -23,12 +78,58 @@ class _Commands(tp.NamedTuple):
     cmds: "tuple[str, ...]"
 
 
+def _yield_accessible_unix_file_names(path):
+    """yield file names of executable files in path."""
+    if not os.path.exists(path):
+        return
+    for file_ in os.scandir(path):
+        if is_executable_in_posix(file_):
+            yield file_.name
+
+
+def _executables_in_posix(path):
+    if not os.path.exists(path):
+        return
+    else:
+        yield from _yield_accessible_unix_file_names(path)
+
+
+def _executables_in_windows(path):
+    if not os.path.isdir(path):
+        return
+    try:
+        for x in os.scandir(path):
+            if is_executable_in_windows(x):
+                yield x.name
+    except FileNotFoundError:
+        # On Windows, there's no guarantee for the directory to really
+        # exist even if isdir returns True. This may happen for instance
+        # if the path contains trailing spaces.
+        return
+
+
+def executables_in(path) -> tp.Iterable[str]:
+    """Returns a generator of files in path that the user could execute."""
+    if ON_WINDOWS:
+        func = _executables_in_windows
+    else:
+        func = _executables_in_posix
+    try:
+        yield from func(path)
+    except PermissionError:
+        return
+
+
 class CommandsCache(cabc.Mapping):
     """A lazy cache representing the commands available on the file system.
     The keys are the command names and the values a tuple of (loc, has_alias)
     where loc is either a str pointing to the executable on the file system or
     None (if no executable exists) and has_alias is a boolean flag for whether
     the command has an alias.
+
+    Note! There is ``xonsh.procs.executables`` module with resolving executables.
+    Usage ``executables`` is preferred instead of commands_cache for cases
+    where you just need to locate executable command.
     """
 
     CACHE_FILE = "path-commands-cache.pickle"
@@ -79,12 +180,7 @@ class CommandsCache(cabc.Mapping):
 
     def iter_commands(self):
         """Wrapper for handling windows path behaviour"""
-        for cmd, (path, is_alias) in self.all_commands.items():
-            if ON_WINDOWS and path is not None:
-                # All command keys are stored in uppercase on Windows.
-                # This ensures the original command name is returned.
-                cmd = pathbasename(path)
-            yield cmd, (path, is_alias)
+        return self.all_commands.items()
 
     def __len__(self):
         return len(self.all_commands)
@@ -98,50 +194,65 @@ class CommandsCache(cabc.Mapping):
         return len(self._cmds_cache) == 0
 
     def get_possible_names(self, name):
-        """Generates the possible `PATHEXT` extension variants of a given executable
-        name on Windows as a list, conserving the ordering in `PATHEXT`.
-        Returns a list as `name` being the only item in it on other platforms."""
-        if ON_WINDOWS:
-            pathext = [""] + self.env.get("PATHEXT", [])
-            name = name.upper()
-            return [name + ext for ext in pathext]
-        else:
-            return [name]
+        return get_possible_names(name, self.env)
 
-    @staticmethod
-    def remove_dups(paths):
-        cont = set()
-        for p in map(os.path.realpath, paths):
-            if p not in cont:
-                cont.add(p)
-                if os.path.isdir(p):
-                    yield p
+    def _update_aliases_cache(self):
+        """Update aliases checksum and return result: updated or not."""
+        prev_hash = self._alias_checksum
+        self._alias_checksum = hash(frozenset(self.aliases))
+        return prev_hash != self._alias_checksum
 
-    def _check_changes(self, paths: tuple[str, ...]):
-        # did PATH change?
-        yield self._update_paths_cache(paths)
+    def _update_and_check_changes(self, paths: tuple[str, ...]):
+        """Update cache and return the result: updated or still the same.
 
-        # did aliases change?
-        al_hash = hash(frozenset(self.aliases))
-        yield al_hash != self._alias_checksum
-        self._alias_checksum = al_hash
+        Be careful in this place. Both `_update_*` functions must be called
+        because they are changing state after update.
+        """
+        is_aliases_change = self._update_aliases_cache()
+        is_paths_change = self._update_paths_cache(paths)
+        return is_aliases_change or is_paths_change
 
     @property
     def all_commands(self):
         self.update_cache()
         return self._cmds_cache
 
+    def resolve_symlink(self, path):
+        visited = set()
+        current_path = path
+        while os.path.islink(current_path):
+            if current_path in visited:
+                # Detected a loop while resolving symlink
+                return None
+            visited.add(current_path)
+            try:
+                current_path = os.readlink(current_path)
+            except Exception:
+                return None
+            if not os.path.isabs(current_path):
+                current_path = os.path.join(os.path.dirname(path), current_path)
+                current_path = os.path.normpath(current_path)
+
+        if current_path == path:
+            return None
+
+        return current_path
+
     def update_cache(self):
+        """The main function to update commands cache.
+        Note! There is ``xonsh.procs.executables`` module with resolving executables.
+        Usage ``executables`` is preferred instead of commands_cache for cases
+        where you just need to locate executable command.
+        """
         env = self.env
         # iterate backwards so that entries at the front of PATH overwrite
         # entries at the back.
-        paths = tuple(reversed(tuple(self.remove_dups(env.get("PATH") or []))))
-        if any(self._check_changes(paths)):
-            all_cmds = {}
+        paths = get_paths(env)
+        if self._update_and_check_changes(paths):
+            all_cmds = CacheDict()
             for cmd, path in self._iter_binaries(paths):
-                key = cmd.upper() if ON_WINDOWS else cmd
                 # None     -> not in aliases
-                all_cmds[key] = (path, None)
+                all_cmds[cmd] = (path, None)
 
             # aliases override cmds
             for cmd in self.aliases:
@@ -156,9 +267,8 @@ class CommandsCache(cabc.Mapping):
                     # (path, False) -> has same named alias
                     all_cmds[override_key] = (all_cmds[override_key][0], False)
                 else:
-                    key = cmd.upper() if ON_WINDOWS else cmd
                     # True -> pure alias
-                    all_cmds[key] = (cmd, True)
+                    all_cmds[cmd] = (cmd, True)
             self._cmds_cache = all_cmds
         return self._cmds_cache
 
@@ -196,13 +306,9 @@ class CommandsCache(cabc.Mapping):
 
     def cached_name(self, name):
         """Returns the name that would appear in the cache, if it exists."""
-        if name is None:
-            return None
         cached = pathbasename(name) if os.pathsep in name else name
-        if ON_WINDOWS:
-            keys = self.get_possible_names(cached)
-            cached = next((k for k in keys if k in self._cmds_cache), None)
-        return cached
+        keys = self.get_possible_names(cached)
+        return next((k for k in keys if k in self._cmds_cache), name)
 
     def lazyin(self, key):
         """Checks if the value is in the current cache without the potential to
@@ -232,6 +338,9 @@ class CommandsCache(cabc.Mapping):
     def locate_binary(self, name, ignore_alias=False):
         """Locates an executable on the file system using the cache.
 
+        NOT RECOMMENDED. Take a look into `xonsh.procs.executables.locate_executable`
+        before using this function.
+
         Parameters
         ----------
         name : str
@@ -240,13 +349,15 @@ class CommandsCache(cabc.Mapping):
             Force return of binary path even if alias of ``name`` exists
             (default ``False``)
         """
-        # make sure the cache is up to date by accessing the property
         self.update_cache()
         return self.lazy_locate_binary(name, ignore_alias)
 
     def lazy_locate_binary(self, name, ignore_alias=False):
         """Locates an executable in the cache, without checking its validity.
 
+        NOT RECOMMENDED. Take a look into `xonsh.procs.executables.locate_executable`
+        before using this function.
+
         Parameters
         ----------
         name : str
@@ -256,12 +367,6 @@ class CommandsCache(cabc.Mapping):
             (default ``False``)
         """
         possibilities = self.get_possible_names(name)
-        if ON_WINDOWS:
-            # Windows users expect to be able to execute files in the same
-            # directory without `./`
-            local_bin = next((fn for fn in possibilities if os.path.isfile(fn)), None)
-            if local_bin:
-                return os.path.abspath(local_bin)
         cached = next((cmd for cmd in possibilities if cmd in self._cmds_cache), None)
         if cached:
             (path, alias) = self._cmds_cache[cached]
@@ -307,18 +412,6 @@ class CommandsCache(cabc.Mapping):
         """
         name = self.cached_name(cmd0)
         predictors = self.threadable_predictors
-        if ON_WINDOWS:
-            # On all names (keys) are stored in upper case so instead
-            # we get the original cmd or alias name
-            path, _ = self.lazyget(name, (None, None))
-            if path is None:
-                return predict_true
-            else:
-                name = pathbasename(path)
-            if name not in predictors:
-                pre, ext = os.path.splitext(name)
-                if pre in predictors:
-                    predictors[name] = predictors[pre]
         if name not in predictors:
             predictors[name] = self.default_predictor(name, cmd0)
         predictor = predictors[name]
@@ -382,6 +475,12 @@ class CommandsCache(cabc.Mapping):
             return failure
         if not os.path.isfile(fname):
             return failure
+        if (link := self.resolve_symlink(fname)) and link.endswith("coreutils"):
+            """
+            On NixOS the core tools are the symlinks to one universal ``coreutils`` binary file.
+            Detect it and use the default mode.
+            """
+            return failure
 
         try:
             fd = os.open(fname, os.O_RDONLY | os.O_NONBLOCK)
