@@ -8,8 +8,6 @@ licensed to the Python Software foundation under a Contributor Agreement.
 """
 
 import collections.abc as cabc
-import functools
-import inspect
 import io
 import os
 import signal
@@ -18,10 +16,11 @@ import sys
 import threading
 import time
 
-import xonsh.lazyimps as xli
+import xonsh.lib.lazyimps as xli
 import xonsh.platform as xp
 import xonsh.tools as xt
 from xonsh.built_ins import XSH
+from xonsh.cli_utils import run_with_partial_args
 from xonsh.procs.readers import safe_fdclose
 
 
@@ -274,7 +273,7 @@ def parse_proxy_return(r, stdout, stderr):
             stdout.write(str(r[0]))
             stdout.flush()
         if rlen > 1 and r[1] is not None:
-            stderr.write(str(r[1]))
+            stderr.write(xt.endswith_newline(str(r[1])))
             stderr.flush()
         if rlen > 2 and isinstance(r[2], int):
             cmd_result = r[2]
@@ -285,67 +284,16 @@ def parse_proxy_return(r, stdout, stderr):
     return cmd_result
 
 
-def proxy_zero(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes no parameters."""
-    return f()
-
-
-def proxy_one(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes one parameter: args"""
-    return f(args)
-
-
-def proxy_two(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes two parameter: args and stdin."""
-    return f(args, stdin)
-
-
-def proxy_three(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes three parameter: args, stdin, stdout."""
-    return f(args, stdin, stdout)
-
-
-def proxy_four(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes four parameter: args, stdin, stdout,
-    and stderr.
-    """
-    return f(args, stdin, stdout, stderr)
-
-
-def proxy_five(f, args, stdin, stdout, stderr, spec, stack):
-    """Calls a proxy function which takes four parameter: args, stdin, stdout,
-    stderr, and spec.
-    """
-    return f(args, stdin, stdout, stderr, spec)
-
-
-PROXIES = (proxy_zero, proxy_one, proxy_two, proxy_three, proxy_four, proxy_five)
-
-
-def partial_proxy(f):
-    """Dispatches the appropriate proxy function based on the number of args."""
-    numargs = 0
-
-    for name, param in inspect.signature(f).parameters.items():
-        # handle *args/**kwargs signature
-        if param.kind in {param.VAR_KEYWORD, param.VAR_POSITIONAL}:
-            numargs = 6
-            break
-        if (
-            param.kind == param.POSITIONAL_ONLY
-            or param.kind == param.POSITIONAL_OR_KEYWORD
-        ):
-            numargs += 1
-        elif name in xt.ALIAS_KWARG_NAMES and param.kind == param.KEYWORD_ONLY:
-            numargs += 1
-    if numargs < 6:
-        return functools.partial(PROXIES[numargs], f)
-    elif numargs == 6:
-        # don't need to partial.
-        return f
-    else:
-        e = "Expected proxy with 6 or fewer arguments for {}, not {}"
-        raise xt.XonshError(e.format(", ".join(xt.ALIAS_KWARG_NAMES), numargs))
+def get_proc_proxy_name(cls):
+    return repr(
+        {
+            "cls": cls.__class__.__name__,
+            "name": getattr(cls, "name", None),
+            "func": cls.f,
+            "alias": cls.env.get("__ALIAS_NAME", None),
+            "pid": cls.pid,
+        }
+    )
 
 
 class ProcProxyThread(threading.Thread):
@@ -392,8 +340,7 @@ class ProcProxyThread(threading.Thread):
         env : Mapping, optional
             Environment mapping.
         """
-        self.orig_f = f
-        self.f = partial_proxy(f)
+        self.f = f
         self.args = args
         self.pid = None
         self.returncode = None
@@ -520,7 +467,17 @@ class ProcProxyThread(threading.Thread):
                 xt.redirect_stderr(STDERR_DISPATCHER),
                 XSH.env.swap(self.env, __ALIAS_STACK=alias_stack),
             ):
-                r = self.f(self.args, sp_stdin, sp_stdout, sp_stderr, spec, spec.stack)
+                r = run_with_partial_args(
+                    self.f,
+                    {
+                        "args": self.args,
+                        "stdin": sp_stdin,
+                        "stdout": sp_stdout,
+                        "stderr": sp_stderr,
+                        "spec": spec,
+                        "stack": spec.stack,
+                    },
+                )
         except SystemExit as e:
             r = e.code if isinstance(e.code, int) else int(bool(e.code))
         except OSError:
@@ -528,7 +485,9 @@ class ProcProxyThread(threading.Thread):
             if status:
                 # stdout and stderr are still writable, so error must
                 # come from function itself.
-                xt.print_exception()
+                xt.print_exception(
+                    source_msg="Exception in thread " + get_proc_proxy_name(self)
+                )
                 r = 1
             else:
                 # stdout and stderr are no longer writable, so error must
@@ -538,7 +497,9 @@ class ProcProxyThread(threading.Thread):
                 # is not truly an error and we should exit gracefully.
                 r = 0
         except Exception:
-            xt.print_exception()
+            xt.print_exception(
+                source_msg="Exception in thread " + get_proc_proxy_name(self)
+            )
             r = 1
         safe_flush(sp_stdout)
         safe_flush(sp_stderr)
@@ -550,7 +511,10 @@ class ProcProxyThread(threading.Thread):
         # clean up
         # scopz: not sure why this is needed, but stdin cannot go here
         # and stdout & stderr must.
-        handles = [self.stdout, self.stderr]
+        if xp.ON_WINDOWS:
+            handles = [self.stdout, self.stderr]
+        else:
+            handles = [sp_stdout, sp_stderr]
         for handle in handles:
             safe_fdclose(handle, cache=self._closed_handle_cache)
 
@@ -778,8 +742,7 @@ class ProcProxy:
         close_fds=False,
         env=None,
     ):
-        self.orig_f = f
-        self.f = partial_proxy(f)
+        self.f = f
         self.args = args
         self.pid = os.getpid()
         self.returncode = None
@@ -818,9 +781,23 @@ class ProcProxy:
         # run the actual function
         try:
             with XSH.env.swap(self.env):
-                r = self.f(self.args, stdin, stdout, stderr, spec, spec.stack)
+                r = run_with_partial_args(
+                    self.f,
+                    {
+                        "args": self.args,
+                        "stdin": stdin,
+                        "stdout": stdout,
+                        "stderr": stderr,
+                        "spec": spec,
+                        "stack": spec.stack,
+                    },
+                )
+        except SystemExit as e:
+            # the alias function is running in the main thread, so we need to
+            # catch SystemExit to prevent the entire shell from exiting (see #5689)
+            r = e.code if isinstance(e.code, int) else int(bool(e.code))
         except Exception:
-            xt.print_exception()
+            xt.print_exception(source_msg="Exception in " + get_proc_proxy_name(self))
             r = 1
         self.returncode = parse_proxy_return(r, stdout, stderr)
         safe_flush(stdout)
