@@ -1,4 +1,5 @@
 """The xonsh configuration (xonfig) utility."""
+
 import ast
 import collections
 import contextlib
@@ -15,10 +16,11 @@ import typing as tp
 import xonsh.wizard as wiz
 from xonsh import __version__ as XONSH_VERSION
 from xonsh.built_ins import XSH
-from xonsh.cli_utils import Annotated, Arg, ArgParserAlias, add_args
+from xonsh.cli_utils import Arg, ArgParserAlias
 from xonsh.events import events
 from xonsh.foreign_shells import CANON_SHELL_NAMES
-from xonsh.lazyasd import lazyobject
+from xonsh.lib.lazyasd import lazyobject
+from xonsh.parsers import ply
 from xonsh.platform import (
     DEFAULT_ENCODING,
     ON_CYGWIN,
@@ -36,7 +38,6 @@ from xonsh.platform import (
     ptk_version,
     pygments_version,
 )
-from xonsh.ply import ply
 from xonsh.prompt.base import is_template_string
 from xonsh.tools import (
     color_style,
@@ -237,7 +238,7 @@ def make_fs_wiz():
                 path="/foreign_shells/{idx}/aliascmd",
             ),
             wiz.StoreNonEmpty(
-                ("extra command line arguments [list of str, " "default=[]]: "),
+                ("extra command line arguments [list of str, default=[]]: "),
                 converter=ast.literal_eval,
                 show_conversion=True,
                 path="/foreign_shells/{idx}/extra_args",
@@ -493,7 +494,7 @@ def _xonfig_format_human(data):
         if isinstance(val, list) and val:
             for i, subval in enumerate(val):
                 s += row.format(
-                    key=f"{key} {i+1}", wcol1=wcol1, val=subval, wcol2=wcol2
+                    key=f"{key} {i + 1}", wcol1=wcol1, val=subval, wcol2=wcol2
                 )
         else:
             s += row.format(key=key, wcol1=wcol1, val=val, wcol2=wcol2)
@@ -560,6 +561,21 @@ def _info(
     data.extend([("xontrib", xontribs_loaded())])
     data.extend([("RC file", XSH.rc_files)])
 
+    # Show sensitive env variables that could affect the shell behavior.
+    envs = {
+        "UPDATE_OS_ENVIRON": None,
+        "XONSH_CAPTURE_ALWAYS": None,
+        "XONSH_SUBPROC_OUTPUT_FORMAT": None,
+        "THREAD_SUBPROCS": None,
+        "ENABLE_ASYNC_PROMPT": True,
+        "ENABLE_COMMANDS_CACHE": False,
+        "XONSH_CACHE_EVERYTHING": True,
+        "XONSH_CACHE_SCRIPTS": None,
+    }
+    for e, show_if in envs.items():
+        if (val := XSH.env.get(e)) is not None and (show_if is None or val == show_if):
+            data.extend([(e, val)])
+
     formatter = _xonfig_format_json if to_json else _xonfig_format_human
     s = formatter(data)
     return s
@@ -639,7 +655,7 @@ def xonfig_color_completer(*_, **__):
 
 
 def _colors(
-    style: Annotated[str, Arg(nargs="?", completer=xonfig_color_completer)] = None
+    style: tp.Annotated[str, Arg(nargs="?", completer=xonfig_color_completer)] = None,
 ):
     """Preview color style
 
@@ -692,7 +708,7 @@ def _web(
 
     from xonsh.webconfig import main
 
-    main.main(_args[1:])
+    main.serve(browser)
 
 
 class XonfigAlias(ArgParserAlias):
@@ -708,8 +724,7 @@ class XonfigAlias(ArgParserAlias):
     def build(self):
         parser = self.create_parser(prog="xonfig")
         # register as default action
-        add_args(parser, _info, allowed_params=())
-        parser.add_command(_info)
+        parser.add_command(_info, default=True)
         parser.add_command(_web)
         parser.add_command(_wizard)
         parser.add_command(_styles)
